@@ -1,10 +1,10 @@
 import os
 from requests import Request, Session
-from Step import Step
+from libs3tl import Step
 import websocket
 
 
-class Extract(Step):
+class Extract(Step.Step):
     def __init__(self):
         self.setStartTime()
         self.step = "Ex"
